Object subclass: #SoapBroker
	instanceVariableNames: 'messageBindings exportSet soapMappingContainer responses '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Core'!

!SoapBroker methodsFor: 'initialize-release' stamp: 'MU 11/12/2000 00:50'!
initialize
	self initializeMessageBindings.
	self initializeExportedSet.
	self initializeMappingContainer! !

!SoapBroker methodsFor: 'initialize-release' stamp: 'MU 11/12/2000 00:50'!
initializeExportedSet
	self exportSet: Dictionary new! !

!SoapBroker methodsFor: 'initialize-release' stamp: 'MU 11/12/2000 00:49'!
initializeMappingContainer
	"Read in interfaceSpec for SoapMappingContainer and SoapDataType "
	| soapTypes xmlDoc |
	xmlDoc := self parser parse: self soapTypesXml.
	soapTypes := self soapTypesFrom: xmlDoc.
	self soapMappingContainer: (SoapMappingContainer new items: soapTypes)! !

!SoapBroker methodsFor: 'initialize-release' stamp: 'MU 11/12/2000 00:48'!
initializeMessageBindings
	self messageBindings: Dictionary new! !


!SoapBroker methodsFor: 'accessing' stamp: 'MU 10/29/2000 01:54'!
envelope

	^envelope! !

!SoapBroker methodsFor: 'accessing' stamp: 'MU 10/29/2000 01:54'!
envelope: anObject

	envelope := anObject! !

!SoapBroker methodsFor: 'accessing'!
exportSet

	^exportSet! !

!SoapBroker methodsFor: 'accessing'!
exportSet: anObject

	exportSet := anObject! !

!SoapBroker methodsFor: 'accessing'!
messageBindings

	^messageBindings! !

!SoapBroker methodsFor: 'accessing'!
messageBindings: anObject

	messageBindings := anObject! !

!SoapBroker methodsFor: 'accessing'!
soapBindings

	^soapBindings! !

!SoapBroker methodsFor: 'accessing'!
soapBindings: anObject

	soapBindings := anObject! !

!SoapBroker methodsFor: 'accessing'!
soapDescriptions

	^soapDescriptions! !

!SoapBroker methodsFor: 'accessing'!
soapDescriptions: anObject

	soapDescriptions := anObject! !

!SoapBroker methodsFor: 'accessing'!
soapMappingContainer

	^soapMappingContainer! !

!SoapBroker methodsFor: 'accessing'!
soapMappingContainer: anObject

	soapMappingContainer := anObject! !


!SoapBroker methodsFor: 'public' stamp: 'MU 10/31/2000 22:58'!
addBinding: aSoapMessageBinding 
	"@aSoapDescription is either a SoapMethodDescription or a 	SoapResponseDescription "
	^ self messageBindings at: aSoapMessageBinding name put: aSoapMessageBinding! !

!SoapBroker methodsFor: 'public' stamp: 'MU 10/31/2000 22:58'!
addDescription: aSoapDescription 
	"@aSoapDescription is either a SoapMethodDescription or a 	SoapResponseDescription "
	^ self soapDescriptions add: aSoapDescription! !

!SoapBroker methodsFor: 'public' stamp: 'MU 10/31/2000 22:59'!
allActorsUsing: aSoapEnvelope 
	| anOrderedCollection |
	anOrderedCollection := OrderedCollection with: self defaultActor.
	anOrderedCollection addAll: aSoapEnvelope actors.
	^ anOrderedCollection! !

!SoapBroker methodsFor: 'public'!
defaultActor

	^SoapActor new! !

!SoapBroker methodsFor: 'public'!
defaultActorWith: aCollection

	^aCollection addFirst: self defaultActor; yourself! !

!SoapBroker methodsFor: 'public' stamp: 'MU 10/31/2000 23:00'!
export: anObject as: aKey 
	self exportSet at: aKey put: anObject! !

!SoapBroker methodsFor: 'public' stamp: 'MU 10/31/2000 23:00'!
extractEnvelopesFrom: aSoapEnvelope 
	"This method is to handle the situation where we have to forward part of the incoming envelop b/c 
	 
	we have actors in the soap header. we will return a collection that contains one or two SoapEnvelopes. 
	 
	if the collection contains one evelope it will be the original envelope.  
	if it contains two envelopes, then they will be two new envelopes, the first for our stuff, the second will be the stuff we forward."
	^ aSoapEnvelope containsActors
		ifTrue: [self halt]
		ifFalse: [OrderedCollection with: aSoapEnvelope]! !

!SoapBroker methodsFor: 'public' stamp: 'MU 11/3/2000 18:50'!
receive: aSoapEnvelope 
	| envelopes  envelope |
	"create a directed message from the @aSoapEnvelope and dispatch it 
	to the receiver. the receiver will be looked up in it's export set. "

	
	envelopes := self extractEnvelopesFrom: aSoapEnvelope.
	envelope := envelopes first. "current support only one"

	envelope broker: self.

	[envelope evaluate ] on: SoapError 
			do:[:ex | Transcript cr; show: '##SOAP ERROR## ', ex messageText.].

	^envelope! !

!SoapBroker methodsFor: 'public' stamp: 'MU 11/7/2000 11:45'!
receiveXml: xmlString
	
	| envelope str |

	envelope := SoapEnvelope fromXml: xmlString.
	str := WriteStream on: (String new: 1024).
	(self receive: envelope ) printXmlOn: str.
	^str contents.! !


!SoapBroker methodsFor: 'dispatching' stamp: 'MU 11/3/2000 00:47'!
dataTypeNamed: aName 
	^ self soapMappingContainer dataTypeNamed: aName ifAbsent: [(SoapError client detail: 'no such data type - ', aName) signal]! !

!SoapBroker methodsFor: 'dispatching' stamp: 'MU 11/3/2000 18:51'!
messageBindingNamed: aName 
	^ self messageBindings at: aName ifAbsent: [(SoapError client detail: 'no message binding - ', aName) signal]! !

!SoapBroker methodsFor: 'dispatching' stamp: 'MU 11/3/2000 00:48'!
objectExportedAs: key 
	^ [exportSet at: key ifAbsent: [(SoapError client detail: 'no such object - ', key ) signal]] valueUninterruptably! !


!SoapBroker methodsFor: 'factory' stamp: 'MU 11/12/2000 00:36'!
parser
	"current not best but most standard Xml parser"
	^VWXMLXMLParser! !

!SoapBroker methodsFor: 'factory' stamp: 'MU 10/31/2000 23:02'!
soapTypesXml
	^self class soapTypesXml! !


!SoapBroker methodsFor: 'private'!
makeSetterMsgFrom: string
	^(string, ':') asSymbol! !

!SoapBroker methodsFor: 'private' stamp: 'MU 11/12/2000 00:51'!
soapTypeFrom: anXMLElement
	
	| soapType elements |
	elements := anXMLElement childNodes.
	soapType := SoapDataType new.
	elements do: [:each |
		| msg element |
		msg := self makeSetterMsgFrom: each tag type.
		element := each characterData.
		soapType perform: msg with: element].
	^soapType! !

!SoapBroker methodsFor: 'private' stamp: 'MU 11/2/2000 22:48'!
soapTypesFrom: xmlDoc
	"answer a collection of SoapDataType objects"

	| typeSection types | 
	typeSection := xmlDoc root.
	types := typeSection childNodes.
	^types collect: [:each |
		each tag type = 'SoapDataType'
			ifTrue: [self soapTypeFrom: each]].! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoapBroker class
	instanceVariableNames: 'default '!

!SoapBroker class methodsFor: 'class initialization' stamp: 'MU 11/12/2000 00:46'!
initialize
	"SoapBroker initialize"
	default := nil! !


!SoapBroker class methodsFor: 'instance creation' stamp: 'MU 11/12/2000 00:46'!
new
	^ super new initialize! !


!SoapBroker class methodsFor: 'default values' stamp: 'MU 11/12/2000 00:46'!
default
	default isNil ifTrue: [default := self new].
	^ default! !

!SoapBroker class methodsFor: 'default values' stamp: 'MU 11/12/2000 00:46'!
soapTypesXml
	^ '<?xml version="1.0"?>
<SoapDataTypes>
<SoapDataType>
	<name>int</name>
	<smalltalkClass>Integer</smalltalkClass>
</SoapDataType>
<SoapDataType>
	<name>float</name>
	<smalltalkClass>Float</smalltalkClass>
</SoapDataType>
<SoapDataType>
	<name>string</name>
	<smalltalkClass>String</smalltalkClass>
</SoapDataType>

</SoapDataTypes>
'! !


!SoapBroker class methodsFor: 'tests' stamp: 'MU 11/12/2000 00:57'!
runBasicTest
	"SoapBroker runBasicTest"
	
	SoapBroker initialize.
	SoapBroker set4BasicTest.
	^SoapBroker default receiveXml: self simpleEnvelope.! !

!SoapBroker class methodsFor: 'tests' stamp: 'mu 10/30/2000 18:56'!
set4BasicTest
	| person soapBroker messageBinding |
	"SoapBroker set4BasicTest"
	person := Cs2Person new.
	person name: 'Adriaaaaan'; age: 25; height: 165; eyeColor: 'blue'.
	soapBroker := SoapBroker default export: person as: 'Person1234'.
	messageBinding := SoapMessageBinding new.
	messageBinding name: 'DoSomething'.
	messageBinding selector: #doSomething:.
	messageBinding addArgument: (SoapArgument
				name: 'symbol'
				dataType: (soapBroker dataTypeNamed: 'string')).	"this needs work"
	soapBroker addBinding: messageBinding.
	^soapBroker
	! !


!SoapBroker class methodsFor: 'fixtures' stamp: 'mu 10/30/2000 11:50'!
errorEnvelope
	
	^'

<SOAP-ENV:Envelope

	xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/"

	SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">

	<SOAP-ENV:Body>

		<m:DoSomeOtherThing xmlns:m="Person1234">

			<symbol>DIS</symbol>

		</m:DoSomeOtherThing>

	</SOAP-ENV:Body>

</SOAP-ENV:Envelope>

'.
! !

!SoapBroker class methodsFor: 'fixtures' stamp: 'MU 10/28/2000 19:16'!
simpleEnvelope
	
	^'

<SOAP-ENV:Envelope

	xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/"

	SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">

	<SOAP-ENV:Body>

		<m:DoSomething xmlns:m="Person1234">

			<symbol>DIS</symbol>

		</m:DoSomething>

	</SOAP-ENV:Body>

</SOAP-ENV:Envelope>

'.
! !


Object subclass: #SoapElement
	instanceVariableNames: 'dom broker '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Core'!

!SoapElement methodsFor: 'initialize-release' stamp: 'MU 10/28/2000 23:05'!
initialize
	"default do nothing"! !


!SoapElement methodsFor: 'accessing' stamp: 'MU 10/29/2000 00:48'!
broker
	^broker! !

!SoapElement methodsFor: 'accessing' stamp: 'MU 10/29/2000 00:48'!
broker: aValue

	broker := aValue! !

!SoapElement methodsFor: 'accessing' stamp: 'mu 10/30/2000 19:20'!
dom
	dom isNil ifTrue: [dom := VWXMLElement tag: 'dummy'. "just for error proof"].
	^dom! !

!SoapElement methodsFor: 'accessing' stamp: 'MU 10/28/2000 23:31'!
dom: aDocumentObjectModel

	dom := aDocumentObjectModel! !


!SoapElement methodsFor: 'actions' stamp: 'MU 10/29/2000 00:59'!
evaluate
	"default do nothing"! !


!SoapElement methodsFor: 'printing' stamp: 'mu 10/30/2000 19:08'!
printXmlOn: stream
	^self dom printOn: stream! !

!SoapElement methodsFor: 'printing' stamp: 'MU 11/7/2000 14:44'!
printXmlString
	| stream |
	stream := WriteStream on: (String new: 1024).
	self dom printOn: stream.
	^stream contents.! !


!SoapElement methodsFor: 'factory' stamp: 'MU 11/7/2000 11:44'!
parser
	
	^self class parser! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoapElement class
	instanceVariableNames: ''!

!SoapElement class methodsFor: 'instance creation' stamp: 'MU 10/28/2000 23:52'!
fromXmlElement: anXmlElement
	^self new dom: anXmlElement! !

!SoapElement class methodsFor: 'instance creation' stamp: 'MU 10/28/2000 23:05'!
new
	^super new initialize! !


!SoapElement class methodsFor: 'constants' stamp: 'MU 10/30/2000 17:05'!
tagName
	^'SOAP-ENV:', (self name copyReplaceAll: 'Soap' with: '')! !


!SoapElement class methodsFor: 'factory' stamp: 'MU 11/7/2000 11:43'!
parser
	"current not best but most standard Xml parser"
	^VWXMLXMLParser! !


SoapElement subclass: #SoapActor
	instanceVariableNames: 'uri '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Core'!

!SoapActor methodsFor: 'accessing'!
uri

	^uri! !

!SoapActor methodsFor: 'accessing'!
uri: anObject

	uri := anObject! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoapActor class
	instanceVariableNames: ''!

!SoapActor class methodsFor: 'instance creation' stamp: 'MU 11/2/2000 23:19'!
uri: aString

	^self new uri: aString! !


SoapElement subclass: #SoapArgument
	instanceVariableNames: 'dataType name value '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Core'!

!SoapArgument methodsFor: 'accessing' stamp: 'MU 10/30/2000 00:32'!
dataType

	^dataType! !

!SoapArgument methodsFor: 'accessing' stamp: 'MU 10/30/2000 00:32'!
dataType: anObject

	dataType := anObject! !

!SoapArgument methodsFor: 'accessing' stamp: 'MU 11/7/2000 14:18'!
name
	name isNil ifTrue:[ name := self dom tag asString].
	^name! !

!SoapArgument methodsFor: 'accessing'!
name: anObject

	name := anObject! !

!SoapArgument methodsFor: 'accessing' stamp: 'MU 11/7/2000 14:19'!
value
	value isNil ifTrue:[value := self dom characterData].
	^value! !

!SoapArgument methodsFor: 'accessing'!
value: anObject

	value := anObject! !


!SoapArgument methodsFor: 'actions' stamp: 'MU 10/30/2000 00:35'!
resolvedValue
	^ self dataType deserialize: self value! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoapArgument class
	instanceVariableNames: ''!

!SoapArgument class methodsFor: 'instance creation' stamp: 'MU 11/2/2000 23:19'!
fromXmlElement: anXmlElement 
	^ (super fromXmlElement: anXmlElement) name: anXmlElement tag asString;
	 value: anXmlElement characterData! !

!SoapArgument class methodsFor: 'instance creation' stamp: 'MU 10/30/2000 00:34'!
name: aString dataType: aSoapDataType 
	^ self
		name: aString
		dataType: aSoapDataType
		value: nil! !

!SoapArgument class methodsFor: 'instance creation' stamp: 'MU 10/30/2000 00:34'!
name: aString dataType: aSoapDataType value: anObject 
	^ super new name: aString;
	 dataType: aSoapDataType;
	 value: anObject! !

!SoapArgument class methodsFor: 'instance creation' stamp: 'MU 11/7/2000 14:15'!
name: tagName value: aValue
	| dom |
	dom := (VWXMLElement tag: tagName elements: (Array with: (VWXMLText text: aValue))). 
	^self fromXmlElement: dom! !


SoapElement subclass: #SoapBody
	instanceVariableNames: 'messages fault '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Core'!

!SoapBody methodsFor: 'actions' stamp: 'MU 11/7/2000 18:29'!
becomeFaultBody: aSoapError
	 "quick hack for fault"
	| fa |
	fa := SoapFault fromSoapError: aSoapError.
	self messages: nil.
	self fault: fa.
	self dom removeAllNodes.
	self dom addNode: (fa dom).! !


!SoapBody methodsFor: 'accessing' stamp: 'MU 10/29/2000 01:29'!
broker: aSoapBroker
	super broker: aSoapBroker.
	self messages do:[:each | each broker: self broker ].! !

!SoapBody methodsFor: 'accessing' stamp: 'MU 11/7/2000 18:10'!
fault
	fault isNil ifTrue: [ | elems |
	elems := (self dom selectNodes: [:each | each tag asString = SoapFault tagName]).
	fault := elems isEmpty ifTrue: [] ifFalse:[SoapFault fromXmlElement: elems first].].
	^ fault! !

!SoapBody methodsFor: 'accessing' stamp: 'MU 11/7/2000 18:28'!
fault: aValue
	fault := aValue! !

!SoapBody methodsFor: 'accessing' stamp: 'MU 11/7/2000 18:37'!
messages
	messages isNil ifTrue: [ | elems |
	elems := (self dom childNodes) select:[:each | each tag qualifier = 'm'].
	messages := elems collect:[:elem | SoapMessage fromXmlElement: elem].].
	^ messages! !

!SoapBody methodsFor: 'accessing' stamp: 'MU 10/28/2000 23:46'!
messages: aValue
	messages := aValue! !


!SoapBody methodsFor: 'testing' stamp: 'MU 11/7/2000 18:41'!
hasFault
	^self fault notNil! !


SoapElement subclass: #SoapDataType
	instanceVariableNames: 'name smalltalkClass serializationBlock deserializationBlock '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Core'!

!SoapDataType methodsFor: 'initialize-release' stamp: 'MU 10/28/2000 15:11'!
initialize
	self serializationBlock: self defaultSerializationBlock;
	 deserializationBlock: self defaultDeserializationBlock! !


!SoapDataType methodsFor: 'actions' stamp: 'MU 11/2/2000 23:21'!
defaultDeserializationBlock

	^[:aClass :aString | aClass fromString: aString ]! !

!SoapDataType methodsFor: 'actions' stamp: 'MU 11/2/2000 23:21'!
defaultSerializationBlock

	"should this return some kind of XML string "

	^[:value | value asString ]! !

!SoapDataType methodsFor: 'actions' stamp: 'MU 11/2/2000 23:21'!
deserialize: aString

	^self deserializationBlock value: self smalltalkClass value: aString! !


!SoapDataType methodsFor: 'accessing' stamp: 'MU 11/2/2000 23:20'!
deserializationBlock

	^deserializationBlock! !

!SoapDataType methodsFor: 'accessing'!
deserializationBlock: anObject

	deserializationBlock := anObject! !

!SoapDataType methodsFor: 'accessing' stamp: 'MU 11/2/2000 23:20'!
name

	^name! !

!SoapDataType methodsFor: 'accessing' stamp: 'MU 11/12/2000 00:52'!
name: aString 
	
	name := aString! !

!SoapDataType methodsFor: 'accessing'!
serializationBlock

	^serializationBlock! !

!SoapDataType methodsFor: 'accessing'!
serializationBlock: anObject

	serializationBlock := anObject! !

!SoapDataType methodsFor: 'accessing' stamp: 'MU 11/2/2000 23:20'!
smalltalkClass

	^smalltalkClass! !

!SoapDataType methodsFor: 'accessing'!
smalltalkClass: aString

	smalltalkClass := self classFrom: aString! !


!SoapDataType methodsFor: 'platform specific' stamp: 'MU 11/2/2000 23:21'!
classFrom: string
	^Smalltalk at: string asSymbol 

! !


SoapElement subclass: #SoapEnvelope
	instanceVariableNames: 'header body '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Core'!

!SoapEnvelope methodsFor: 'actions'!
actors

	| anOrderedCollection |
	anOrderedCollection := OrderedCollection new.
	^self header isNil
		ifTrue:[anOrderedCollection]
		ifFalse:[self extractActorsInto: anOrderedCollection]! !

!SoapEnvelope methodsFor: 'actions' stamp: 'MU 11/7/2000 18:29'!
evaluate
	[self body messages
		do: [:each | each evaluate]]
		on: SoapError
		do: [:ex | "quick hack for fault"
		self body becomeFaultBody: ex.
		ex pass]! !

!SoapEnvelope methodsFor: 'actions' stamp: 'MU 10/28/2000 23:38'!
extractActorsInto: aCollection

	" figure this out later use the header extract them"

	^aCollection! !

!SoapEnvelope methodsFor: 'actions' stamp: 'MU 10/29/2000 00:54'!
messages
	" self processHeaderInformation "
	^self body messages! !


!SoapEnvelope methodsFor: 'accessing' stamp: 'MU 10/30/2000 17:06'!
body
	body isNil ifTrue: [ | elems |
	elems := (self dom selectNodes: [:each | each tag asString = SoapBody tagName]).
	body := elems isEmpty ifTrue: [] ifFalse:[SoapBody fromXmlElement: elems first]].
	^ body! !

!SoapEnvelope methodsFor: 'accessing' stamp: 'MU 10/28/2000 19:56'!
body: aSoapBody
	body := aSoapBody! !

!SoapEnvelope methodsFor: 'accessing' stamp: 'MU 10/29/2000 01:30'!
broker: aSoapBroker
	super broker: aSoapBroker.
	self header isNil ifFalse: [ self header broker: aSoapBroker].
	self body isNil ifFalse: [self body broker: aSoapBroker]! !

!SoapEnvelope methodsFor: 'accessing' stamp: 'MU 10/30/2000 17:06'!
header
	header isNil ifTrue: [ | elems |
	elems := (self dom selectNodes: [:each | each tag asString = SoapHeader tagName]).
	header := elems isEmpty ifTrue: [] ifFalse:[SoapBody fromXmlElement: elems first]].
	^ header! !

!SoapEnvelope methodsFor: 'accessing' stamp: 'MU 10/28/2000 23:21'!
header: aSoapHeader
	header := aSoapHeader! !


!SoapEnvelope methodsFor: 'testing' stamp: 'MU 11/2/2000 23:22'!
containsActors
	^false! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoapEnvelope class
	instanceVariableNames: ''!

!SoapEnvelope class methodsFor: 'instance creation' stamp: 'MU 11/7/2000 11:45'!
fromXml: xmlString
	^self fromXmlDocument: (self parser parse: xmlString).! !

!SoapEnvelope class methodsFor: 'instance creation' stamp: 'MU 10/30/2000 17:05'!
fromXmlDocument: anXmlDocument 
	"Create a new SoapEnvelope that wraps the passed XmlDocument 
	
	element or one of its children"
	"##cha"
	| element elements |
	(element := anXmlDocument root) tag asString = self tagName
		ifFalse: [(elements := element selectNodes: [:each | each tag asString = self tagName]) isEmpty ifFalse: [element := elements first]].
	^ (element isNil or: [element tag asString ~= self tagName])
		ifTrue: [self error: #'No SOAP Envelope']
		ifFalse: [self new dom: element]! !


Error subclass: #SoapError
	instanceVariableNames: 'faultCode '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Core'!

!SoapError methodsFor: 'accessing' stamp: 'MU 11/3/2000 00:10'!
detail
	^self messageText! !

!SoapError methodsFor: 'accessing' stamp: 'MU 11/3/2000 00:08'!
detail: aString
	self messageText: aString! !

!SoapError methodsFor: 'accessing' stamp: 'MU 11/2/2000 23:32'!
faultCode
	^faultCode! !

!SoapError methodsFor: 'accessing' stamp: 'MU 11/2/2000 23:31'!
faultCode: aValue
	faultCode := aValue! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoapError class
	instanceVariableNames: ''!

!SoapError class methodsFor: 'instance creation' stamp: 'MU 11/7/2000 19:18'!
faultCode: aFaultCodeSymbol
	^self new faultCode: aFaultCodeSymbol! !

!SoapError class methodsFor: 'instance creation' stamp: 'MU 11/7/2000 20:05'!
fromSoapFault: aSoapFault
	| inst |
	inst := self faultCode: aSoapFault faultcode.
	inst detail: aSoapFault detail.
	^inst ! !


!SoapError class methodsFor: 'defaults' stamp: 'MU 11/7/2000 19:18'!
client
	^self faultCode: #Client! !

!SoapError class methodsFor: 'defaults' stamp: 'MU 11/7/2000 19:18'!
mustUnderstand
	^self faultCode: #MustUnderstand! !

!SoapError class methodsFor: 'defaults' stamp: 'MU 11/7/2000 19:18'!
server
	^self faultCode: #Server! !

!SoapError class methodsFor: 'defaults' stamp: 'MU 11/7/2000 19:19'!
versionMismatch
	^self faultCode: #VersionMismatch! !


SoapElement subclass: #SoapFault
	instanceVariableNames: 'faultcode faultstring faultactor detail '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Core'!

!SoapFault methodsFor: 'testing' stamp: 'MU 11/7/2000 17:47'!
isFault
	^true! !


!SoapFault methodsFor: 'accessing' stamp: 'MU 11/7/2000 19:59'!
detail
	detail isNil
		ifTrue: [| det | 
			det := self dom childNodes
						detect: [:each | each tag type = 'detail']
						ifNone: [].
			det isNil
				ifFalse: [| msgElem | 
					msgElem := det childNodes first childNodes first.
					detail := msgElem characterData]].
	^ detail! !

!SoapFault methodsFor: 'accessing' stamp: 'MU 11/7/2000 19:33'!
detail: aValue

	detail := aValue! !

!SoapFault methodsFor: 'accessing' stamp: 'MU 11/7/2000 19:33'!
faultactor

	^faultactor! !

!SoapFault methodsFor: 'accessing' stamp: 'MU 11/7/2000 19:33'!
faultactor: aValue

	faultactor := aValue! !

!SoapFault methodsFor: 'accessing' stamp: 'MU 11/7/2000 19:48'!
faultcode
	faultcode isNil ifTrue: [ | elem |
		elem := self dom childNodes detect:[:each | each tag type = 'faultcode'] ifNone:[].
		faultcode := (elem characterData copyReplaceAll: 'SOAP-ENV:' with: '') asSymbol.
	].
	^faultcode! !

!SoapFault methodsFor: 'accessing' stamp: 'MU 11/7/2000 19:33'!
faultcode: aValue

	faultcode := aValue! !

!SoapFault methodsFor: 'accessing' stamp: 'MU 11/7/2000 19:50'!
faultstring
	faultstring isNil ifTrue: [ | elem |
		elem := self dom childNodes detect:[:each | each tag type = 'faultstring'] ifNone:[].
		faultstring := elem characterData.
	].
	^faultstring! !

!SoapFault methodsFor: 'accessing' stamp: 'MU 11/7/2000 19:33'!
faultstring: aValue

	faultstring := aValue! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoapFault class
	instanceVariableNames: ''!

!SoapFault class methodsFor: 'instance creation' stamp: 'MU 11/3/2000 00:08'!
fromSoapError: aSoapError
	| xml parsed |
	xml := aSoapError detail isNil ifTrue: [  self errorXmlOf: aSoapError faultCode ] 
								ifFalse:[ self errorXmlOf: aSoapError faultCode detail: aSoapError detail ].
	parsed := (self parser parse: xml) root.
	
	"VWXMLParser is too formal. So remove unneeded attributes"
	parsed attributes: nil.
	
	^self fromXmlElement: parsed! !


!SoapFault class methodsFor: 'utility' stamp: 'MU 11/1/2000 00:15'!
errorXmlOf: aSymbol
	^ '<', self tagName , ' xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/">
           <faultcode>SOAP-ENV:', aSymbol, '</faultcode>
           <faultstring>', aSymbol, ' Error</faultstring>' , '</', self tagName, '>'! !

!SoapFault class methodsFor: 'utility' stamp: 'MU 11/3/2000 00:09'!
errorXmlOf: aSymbol detail: aDetailString 
	^ '<', self tagName , ' xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/">
           <faultcode>SOAP-ENV:', aSymbol, '</faultcode>
           <faultstring>', aSymbol, ' Error</faultstring>
           	<detail>
                   <e:details xmlns:e="http://www.mars.dti.ne.jp/~umejava/smalltalk/soapOpera/">
                     <message>', aDetailString, '</message>
                   </e:details>
           </detail>
		' , '</', self tagName, '>'! !


SoapElement subclass: #SoapHeader
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Core'!


Object subclass: #SoapMappingContainer
	instanceVariableNames: 'items '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Core'!

!SoapMappingContainer methodsFor: 'actions' stamp: 'MU 11/3/2000 00:46'!
dataTypeNamed: aName

	^self dataTypeNamed: aName ifAbsent: []! !

!SoapMappingContainer methodsFor: 'actions' stamp: 'MU 11/3/2000 00:46'!
dataTypeNamed: aName ifAbsent: aBlock

	^self items detect: [:each | each name = aName ] ifNone: [aBlock value]! !


!SoapMappingContainer methodsFor: 'accessing' stamp: 'MU 11/2/2000 23:22'!
items

	^items! !

!SoapMappingContainer methodsFor: 'accessing' stamp: 'MU 11/2/2000 23:22'!
items: anOrderedCollection

	items := anOrderedCollection! !


SoapElement subclass: #SoapMessage
	instanceVariableNames: 'receiver arguments name result '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Core'!

!SoapMessage methodsFor: 'actions' stamp: 'MU 11/10/2000 21:36'!
evaluate
	"raise error if evaluatein fails"
	| resultDom |
	[self result: self asDirectedMessage value]
		on: Error
		do: [:ex | (ex isKindOf: SoapError)
				ifTrue: [ex pass]
				ifFalse: [| rec | 
					rec := ex class name == #MessageNotUnderstood
								ifTrue: [': ' , ex receiver printString , ' > ']
								ifFalse: [' > '].
					ex
						resignalAs: (SoapError server detail: ex class name , rec , ex messageText)]].
	"succeed - make response"
	self name: self name , 'Response'.
	resultDom := VWXMLElement
				tag: self result class name asString
				elements: (Array
						with: (VWXMLText text: self result storeString)).
	self dom removeAllNodes.
	self dom addNode: resultDom! !


!SoapMessage methodsFor: 'converting' stamp: 'MU 11/2/2000 23:24'!
asDirectedMessage
	| aDirectedMessage aMessageBinding |
	aMessageBinding := self broker messageBindingNamed: self name.
	
	aDirectedMessage := MessageSend
				receiver: (self broker objectExportedAs: self receiver)
				selector: aMessageBinding selector
				arguments: (self argumentsUsing: aMessageBinding) asArray.
	^ aDirectedMessage! !


!SoapMessage methodsFor: 'accessing' stamp: 'MU 10/29/2000 01:21'!
arguments
	arguments isNil ifTrue:[
		arguments :=  self dom childNodes collect: [:each | SoapArgument fromXmlElement: each ] 
	].
	^arguments! !

!SoapMessage methodsFor: 'accessing' stamp: 'MU 11/7/2000 14:06'!
arguments: aCollectionOfSoapArgument 
	self dom removeAllNodes.
	aCollectionOfSoapArgument
		do: [:each | self dom addNode: each dom].
	arguments := aCollectionOfSoapArgument! !

!SoapMessage methodsFor: 'accessing' stamp: 'MU 11/2/2000 22:55'!
name
	name isNil ifTrue: [
	name := (self dom tag type). "##must remove m:"].
	^name! !

!SoapMessage methodsFor: 'accessing' stamp: 'MU 11/7/2000 17:11'!
name: aString
	| tg |
	tg := self dom tag.
	tg
		qualifier: tg qualifier
		ns: tg namespace
		type: aString.
	name := aString! !

!SoapMessage methodsFor: 'accessing' stamp: 'MU 10/30/2000 17:27'!
receiver
	| mAttrib |
	mAttrib := VWXMLNodeTag new qualifier: 'xmlns' ns: '<!!-- xml namespace -->' type: 'm'.
	receiver isNil ifTrue: [receiver := self dom valueOfAttribute: mAttrib ifAbsent: []].
	^ receiver! !

!SoapMessage methodsFor: 'accessing' stamp: 'MU 11/7/2000 17:11'!
receiver: aString
	| att |
	att := self dom
				attributeNamed: (VWXMLNodeTag new
						qualifier: 'xmlns'
						ns: '<!!-- xml namespace -->'
						type: 'm').
	att value: aString.
	receiver := aString! !

!SoapMessage methodsFor: 'accessing' stamp: 'MU 11/10/2000 20:37'!
result
	"##needs more work##"
	result isNil ifTrue:[
		result :=  self dom childNodes first characterData.
	].
	^result! !

!SoapMessage methodsFor: 'accessing' stamp: 'MU 10/29/2000 01:22'!
result: anObject

	result := anObject! !


!SoapMessage methodsFor: 'private' stamp: 'MU 10/30/2000 00:33'!
argumentsUsing: aMessageBinding
	"take an argument that was passed over the wire and reconcile 
	it to the 'template' argument that was bound in a message binding"
	^ self arguments
		collect: 
			[:unboundArgument | 
			| boundArgument | 
			boundArgument := aMessageBinding arguments detect: [:each | each name = unboundArgument name]
						ifNone: [self halt].
			unboundArgument dataType: boundArgument dataType.
			unboundArgument resolvedValue]! !


!SoapMessage methodsFor: 'testing' stamp: 'MU 11/7/2000 17:46'!
isFault
	^false! !


Object subclass: #SoapMessageBinding
	instanceVariableNames: 'arguments selector name '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Core'!

!SoapMessageBinding methodsFor: 'initialize-release' stamp: 'MU 11/2/2000 23:25'!
initialize

	self initializeArguments.! !

!SoapMessageBinding methodsFor: 'initialize-release' stamp: 'MU 11/2/2000 23:25'!
initializeArguments

	self arguments: OrderedCollection new! !


!SoapMessageBinding methodsFor: 'accessing' stamp: 'MU 10/30/2000 00:38'!
arguments

	arguments isNil ifTrue: [arguments := OrderedCollection new].

	^arguments! !

!SoapMessageBinding methodsFor: 'accessing' stamp: 'MU 11/2/2000 23:25'!
arguments: aCollection

	arguments := aCollection! !

!SoapMessageBinding methodsFor: 'accessing'!
name

	^name! !

!SoapMessageBinding methodsFor: 'accessing'!
name: anObject

	name := anObject! !

!SoapMessageBinding methodsFor: 'accessing'!
selector

	^selector! !

!SoapMessageBinding methodsFor: 'accessing'!
selector: anObject

	selector := anObject! !


!SoapMessageBinding methodsFor: 'actions' stamp: 'MU 10/30/2000 00:37'!
addArgument: aSoapArgument 
	"the order of the arguments is important. we will use this order 	to build the directed message. 
	we will lookup the arguments by name in the incoming domelement and convert the value based on the soapdatatype"
	
	^ self arguments addLast: aSoapArgument! !

!SoapMessageBinding methodsFor: 'actions' stamp: 'MU 11/2/2000 23:25'!
asDirectedMessage

	" will return a SoapMessage "! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoapMessageBinding class
	instanceVariableNames: ''!

!SoapMessageBinding class methodsFor: 'instance creation' stamp: 'MU 11/2/2000 23:25'!
new

	^super new initialize! !

SoapBroker initialize!