Object subclass: #SoapHttpClient
	instanceVariableNames: ''
	classVariableNames: 'CrLf '
	poolDictionaries: ''
	category: 'SOAP-Http'!

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoapHttpClient class
	instanceVariableNames: ''!

!SoapHttpClient class methodsFor: 'class initialization' stamp: 'MU 10/28/2000 15:35'!
initialize
	"SoapClient initialize"
	CrLf := String with: Character cr with: Character lf.! !


!SoapHttpClient class methodsFor: 'utility' stamp: 'MU 10/28/2000 16:01'!
forkSendTo: url request: xmlString
	
	^[self sendTo: url request: xmlString] fork! !

!SoapHttpClient class methodsFor: 'utility' stamp: 'MU 11/12/2000 01:20'!
sendTo: url request: soapEnvelopeXmlString
	
	"dirty, copied from HttpSocket"
	| serverName serverAddr s header bare page list firstData aStream port specifiedServer frm length newUrl con |

	Socket initializeNetwork.

	"parse url"
	bare := (url asLowercase beginsWith: 'http://') 
		ifTrue: [url copyFrom: 8 to: url size]
		ifFalse: [url].
	serverName := bare copyUpTo: $/.
	specifiedServer := serverName.
	(serverName includes: $:) ifFalse: [ port := '80' ] ifTrue: [
		port := (serverName copyFrom: (serverName indexOf: $:) + 1 
				to: serverName size) asNumber.
		serverName := serverName copyUpTo: $:.
	].

	(frm := (bare indexOf: $/) ) = 0 ifTrue:[frm := 1].
	page := bare copyFrom: frm to: bare size.
	page size = 0 ifTrue: [page := '/'].

  	"make the request"	
	HTTPSocket retry: [serverAddr := NetNameResolver addressForName: serverName timeout: 20.
				serverAddr ~~ nil] 
		asking: 'Trouble resolving server name.  Keep trying?'
		ifGiveUp: [^ 'Could not resolve the server named: ', serverName].

	s := HTTPSocket new.
	s connectTo: serverAddr port: port.
	s waitForConnectionUntil: Socket standardDeadline.
	s sendCommand: 'POST ', page, ' HTTP/1.0', CrLf, 
		'ACCEPT: text/xml', CrLf,
		'User-Agent: ', Smalltalk version, CrLf,
		'Content-type: text/xml', CrLf,
		'Content-length: ', soapEnvelopeXmlString size printString, CrLf,
		'Host: ', specifiedServer, CrLf, CrLf, soapEnvelopeXmlString,
		'SOAPAction:'.

	"get the header of the reply"
	list := s getResponseUpTo: CrLf, CrLf ignoring: (String with: Character cr).	"list = header, CrLf, CrLf, beginningOfData"
	header := list at: 1.
	firstData := list at: 3.
	
	"Transcript cr; show: 'header: ', header, ' data: ', firstData."

	"dig out some headers"
	s header: header.
	length := s getHeader: 'content-length'.
	length ifNotNil: [ length := length asNumber ].
	s responseCode first = $3 ifTrue: [
		newUrl := s getHeader: 'location'.
		newUrl ifNotNil: [
			Transcript show: 'redirecting to: ', newUrl; cr.
			s destroy.
			^self sendTo: newUrl request: soapEnvelopeXmlString ] ].

	aStream := s getRestOfBuffer: firstData totalLength: length.
	con := aStream contents.
	s responseCode = '401' ifTrue: [^ header, con].
	s destroy.	"Always OK to destroy!!"
	^con
	
	 ! !


!SoapHttpClient class methodsFor: 'tests' stamp: 'MU 11/7/2000 11:17'!
test1
	"SoapHttpClient test1 "
	"(print it)"
	^SoapHttpClient sendTo: 'localhost:8823' request: SoapBroker simpleEnvelope! !

!SoapHttpClient class methodsFor: 'tests' stamp: 'MU 11/7/2000 11:17'!
test2
	"SoapHttpClient test2"
	"(print it)"
	^SoapHttpClient sendTo: 'localhost:8823' request: SoapBroker errorEnvelope! !

!SoapHttpClient class methodsFor: 'tests' stamp: 'MU 11/7/2000 11:19'!
testInit
	"SoapHttpClient testInit "
	SoapBroker initialize.
	SoapBroker set4BasicTest.! !


ComancheModule subclass: #SoapHttpModule
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Http'!

!SoapHttpModule methodsFor: 'processing' stamp: 'MU 11/12/2000 01:18'!
process: request
	| rawXml ret |
	
	(request contentType = MIMEDocument contentTypeXml)
	ifFalse:[^nil].
	
	rawXml := request stream next: request contentLength. "body"

	"Transcript show: 'reqBody: ', rawXml printString." "##for debug##"
	
	ret := SoapBroker default receiveXml: rawXml.
	
	^HttpResponse fromMIMEDocument: 
		(MIMEDocument contentType: 'text/xml' content: ret)
	
	
	
	! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoapHttpModule class
	instanceVariableNames: ''!

!SoapHttpModule class methodsFor: 'instance creation' stamp: 'MU 10/28/2000 16:21'!
soapHttpServer
	| instance |
	instance := self newModuleNamed: 'SOAP'.
	^instance! !


Object subclass: #SoapHttpModuleSetup
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Http'!

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoapHttpModuleSetup class
	instanceVariableNames: ''!

!SoapHttpModuleSetup class methodsFor: 'utility' stamp: 'MU 11/5/2000 01:04'!
launch
	| po launcher |
	"SoapHttpModuleSetup launch"
	po := OperaSetting default defaultPort.
	launcher := ComSwikiLauncher openAsMorphPackage: #soapHttpServer.
	launcher ports: ((OrderedCollection withAll: #(80 8080 8888)) add: po; yourself).
	launcher port: po.
	^launcher! !

SoapHttpClient initialize!